<?php

namespace Includes\Admin;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

/**
 * This class is used to genrate pdf file of quotation.
 */
class QuoteupGeneratePdf
{
    /**
     * Function is used to genrate pdf.
     */
    public static function generatePdf()
    {
        do_action('wdm_before_create_pdf', isset($_POST['language']) ? $_POST['language'] : 'all');
        global $wpdb, $quoteup;
        $enquiry_tbl = $wpdb->prefix.'enquiry_detail_new';
        $quotation_tbl = $wpdb->prefix.'enquiry_quotation';
        $enquiry_id = $_POST[ 'enquiry_id' ];
        $show_price = isset($_POST[ 'show-price' ]) ? $_POST[ 'show-price' ] : '0';
        //Get data of enquiry details
        $enquiry_details = $wpdb->get_row($wpdb->prepare("SELECT name, email, product_details FROM $enquiry_tbl WHERE enquiry_id = %d", $enquiry_id));
        //Get data of Quotation(Updated price and Quantity)
        $quotation = $wpdb->get_results($wpdb->prepare("SELECT * FROM $quotation_tbl WHERE enquiry_id = %d", $enquiry_id), ARRAY_A);

        //Get Plugin setttings in selected Language
        add_filter('icl_current_string_language', array(__CLASS__, 'setQuoteLanguage'));
        $pdfSetting = get_option('wdm_form_data');
        remove_filter('icl_current_string_language', array(__CLASS__, 'setQuoteLanguage'));

        $name = $enquiry_details->name;
        $mail = $enquiry_details->email;
        $expiration_date = $quoteup->manageExpiration->getExpirationDate($_POST[ 'enquiry_id' ]);

        //Genrate hash for this enquiry id
        $hash = quoteupEnquiryHashGenerator($enquiry_id);

        //update Hash in database(enquiry_detail_new) Table
        \updateHash($enquiry_id, $hash);
        //Genrate Unique URL For Approve or reject
        $uniqueURL = quoteLinkGenerator($hash);
        if (empty($uniqueURL)) {
            echo 'ERROR';
            die();
        }

        ob_start();
        $args = array(
            'pdfSetting' => $pdfSetting,
            'enquiry_id' => $enquiry_id,
            'name' => $name,
            'mail' => $mail,
            'show_price' => $show_price,
            'enquiry_details' => $enquiry_details,
            'uniqueURL' => $uniqueURL,
            'quotation' => $quotation,
            'expiration_date' => $expiration_date,
            );

        //This loads the template for PDF
        quoteupGetAdminTemplatePart('pdf-quote/quote-pdf', '', $args);

        do_action('wdm_after_create_pdf');

        $html = ob_get_clean();

        self::createFontsDirectory();

        require_once 'mpdf/mpdf.php';
        $stylesheet = file_get_contents(QUOTEUP_PLUGIN_DIR.'/css/admin/pdf-generation.css');
        $upload_dir = wp_upload_dir();
        $path = $upload_dir[ 'basedir' ].'/QuoteUp_PDF/';
        $mpdf = new \mPDF();
        $mpdf->useAdobeCJK = true;
        $mpdf->autoScriptToLang = true;
        $mpdf->autoLangToFont = true;
        $mpdf->WriteHTML($stylesheet, 1);
        $mpdf->WriteHtml($html, 2);

        $mpdf->Output($path.$enquiry_id.'.pdf', 'F');
        die;
    }

    public static function setQuoteLanguage()
    {
        return isset($_POST['language']) ? $_POST['language'] : 'all';
    }
    /**
     * This function is used to Create a font file if it does not exist in fonts.
     */
    public static function createFontsDirectory()
    {
        if (!defined('_MPDF_CUSTOM_TTFONTPATH')) {
            $upload_dir = wp_upload_dir();
            $quoteup_custom_font_dir = $upload_dir[ 'basedir' ].'/custom_fonts/';
            define('_MPDF_CUSTOM_TTFONTPATH', $quoteup_custom_font_dir);
            if (!file_exists(_MPDF_CUSTOM_TTFONTPATH)) {
                wp_mkdir_p(_MPDF_CUSTOM_TTFONTPATH);
            }
        }
    }
}
